.. PySensors documentation master file, created by
   sphinx-quickstart on Tue Oct  4 13:32:08 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to PySensors's documentation!
=====================================

Contents:

.. toctree::
   :maxdepth: 2


Overview
========


Requirements
------------

* Python (>=2.6) and <3,
* version 3.x of :file:`libsensors.so` from ``lm-sensors``.


Executing the package as program
================================

.. module:: sensors.cli

The :mod:`sensors.cli` module can be started as a program with the :option:`-m`
command line option of Python.  It simply…


The :mod:`sensors` package
==========================

.. module:: sensors


:class:`Chip` objects
---------------------

.. class:: Chip


:class:`Feature` objects
------------------------

.. class:: Feature


:class:`Subfeature` objects
---------------------------

.. class:: Subfeature


Environment
===========

:envvar:`SENSORS_LIB`


License
=======

LGPL v2.1 or later.


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

